{% extends "lyra/reserve.html" %}

{% load i18n %}

{% block content_title %}{% trans "Change the menu" %}{% endblock %}
{% block submit_text %}{% trans "Save changes" %}{% endblock %}

{% block form_body %}
<div class="column_container">
{% for form in forms %}
<div class="inlineblock column">
  <h3>{{ form.date|date:"l j.n"|capfirst }}</h3>
  {% for field in form %}
  <div>
    <h4>{{ field.label_tag }}</h4>
    <p {% if field.errors %}class="errors"{% endif %}>{{ field }}</p>
    <p class="help">{{ field.help_text }}</p>
    {% if field.errors %}{{ errors }}{% endif %}
  </div>
  {% endfor %}
</div>
{% endfor %}
</div>
{% endblock %}
