{% extends "base.html" %}

{% block css %}
<link rel="stylesheet" href="{{ MEDIA_URL }}lyra/css/lyra.css">
{% endblock %}

{% block js %}
<script type="text/javascript" src="{{ MEDIA_URL }}lyra/js/lyra.js"></script>
{% endblock %}

{% block content %}

<h2>{{ app_name }}: {% block content_title %}{% endblock %}</h2>

{% block content_navi %}{% endblock %}

{% block content_body %}{% endblock %}

{% endblock %}

