{% extends base %}

{% load i18n %}

{% block content_title %}{% trans "Forbidden" %}{% endblock %}

{% block content_body %}{% trans "You do not have permission to access this page." %}{% endblock %}
